from distutils.core import setup
setup(
    name='boundary',
    version='0.0.7',
    url="https://github.com/boundary/boundary-api-cli",
    author='David Gwartney',
    author_email='davidg@boundary.com',
    packages=['boundary',],
    scripts=[
      'bin/alarm-create',
      'bin/alarm-list',
      'bin/action-installed',
      'bin/action-types',
      'bin/hostgroup-create',
      'bin/hostgroup-delete',
      'bin/hostgroup-get',
      'bin/hostgroup-list',
      'bin/hostgroup-update',
      'bin/measurement-create',
      'bin/measurement-get',
      'bin/metric-create',
      'bin/metric-delete',
      'bin/metric-export',
      'bin/metric-import',
      'bin/metric-list',
      'bin/metric-markdown',
      'bin/metric-ref',
      'bin/plugin-add',
      'bin/plugin-get',
      'bin/plugin-get-components',
      'bin/plugin-list',
      'bin/plugin-install',
      'bin/plugin-installed',
      'bin/plugin-remove',
      'bin/plugin-uninstall',
      'bin/relay-list',
      'bin/user-get',
    ],
    license='LICENSE.txt',
    description='Command line interface to Boundary REST APIs',
    long_description=open('README.txt').read(),
    install_requires=[
        "requests >= 2.3.0",
        "python-dateutil >= 2.4.1",
    ],
)

